@@ -20,8 +20,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef MASSIFDATA_PARSETHREAD_H
-#define MASSIFDATA_PARSETHREAD_H
+#ifndef MASSIFDATA_PARSEWORKER_H
+#define MASSIFDATA_PARSEWORKER_H
 
 #include <QThread>
 #include <QStringList>
@@ -37,7 +37,7 @@ class ParseWorker : public QObject
     Q_OBJECT
 
 public:
-    explicit ParseWorker(QObject* parent = 0);
+    explicit ParseWorker(QObject* parent = nullptr);
 
     void stop();
 
@@ -64,4 +64,4 @@ private:
 
 }
 
-#endif // MASSIFDATA_PARSETHREAD_H
+#endif // MASSIFDATA_PARSEWORKER_H
