@@ -23,8 +23,8 @@
 #ifndef MASSIF_DETAILEDCOSTMODEL_H
 #define MASSIF_DETAILEDCOSTMODEL_H
 
-#include <QtCore/QAbstractTableModel>
-#include <QtCore/QVector>
+#include <QAbstractTableModel>
+#include <QList>
 
 #include "modelitem.h"
 
@@ -40,18 +40,18 @@ class TreeLeafItem;
 class DetailedCostModel : public QAbstractTableModel
 {
 public:
-    DetailedCostModel(QObject* parent = 0);
-    virtual ~DetailedCostModel();
+    explicit DetailedCostModel(QObject* parent = nullptr);
+    ~DetailedCostModel() override;
 
     /**
      * That the source data for this model.
      */
     void setSource(const FileData* data);
 
-    virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
-    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
-    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
     /**
      * Sets the maximum number of datasets in this model to @p count.
@@ -104,10 +104,10 @@ public:
 private:
     const FileData* m_data;
     // columns => label
-    QVector<QByteArray> m_columns;
+    QList<QByteArray> m_columns;
     // only to sort snapshots by number
-    QVector<const SnapshotItem*> m_rows;
-    typedef QHash<const SnapshotItem*, QVector<const TreeLeafItem*> > Nodes;
+    QList<const SnapshotItem*> m_rows;
+    typedef QHash<const SnapshotItem*, QList<const TreeLeafItem*> > Nodes;
     // snapshot item => cost intensive nodes
     Nodes m_nodes;
     // peaks: Label => TreeLeafItem,Snapshot
